==> pmml-sklearn-1.7.51-sources.jar: sklearn/dummy/DummyRegressor.java <==
/*
 * Copyright (c) 2017 Villu Ruusmann
 *
 * This file is part of JPMML-SkLearn
 *
 * JPMML-SkLearn is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPMML-SkLearn is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with JPMML-SkLearn.  If not, see <http://www.gnu.org/licenses/>.
 */
package sklearn.dummy;

import java.util.Collections;
import java.util.List;

import com.google.common.collect.Iterables;
import org.dmg.pmml.regression.RegressionModel;
import org.jpmml.converter.Schema;
import org.jpmml.converter.regression.RegressionModelUtil;
import sklearn.HasDefaultValue;
import sklearn.SkLearnRegressor;

public class DummyRegressor extends SkLearnRegressor implements HasDefaultValue {

	public DummyRegressor(){
		this("sklearn.dummy", "DummyRegressor");
	}

	public DummyRegressor(String module, String name){
		super(module, name);
	}

	@Override
	public Number getDefaultValue(){
		List<? extends Number> constant = getConstant();

		return Iterables.getOnlyElement(constant);
	}

	@Override
	public RegressionModel encodeModel(Schema schema){
		List<? extends Number> constant = getConstant();

		Number intercept = Iterables.getOnlyElement(constant);

		return RegressionModelUtil.createRegression(Collections.emptyList(), Collections.emptyList(), intercept.doubleValue(), null, schema);
	}

	public List<? extends Number> getConstant(){
		return getNumberArray("constant_");
	}
}

==> pmml-sklearn-1.8.2-sources.jar: sklearn/dummy/DummyRegressor.java <==
/*
 * Copyright (c) 2017 Villu Ruusmann
 *
 * This file is part of JPMML-SkLearn
 *
 * JPMML-SkLearn is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPMML-SkLearn is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with JPMML-SkLearn.  If not, see <http://www.gnu.org/licenses/>.
 */
package sklearn.dummy;

import java.util.Collections;
import java.util.List;

import com.google.common.collect.Iterables;
import org.dmg.pmml.regression.RegressionModel;
import org.jpmml.converter.Schema;
import org.jpmml.converter.regression.RegressionModelUtil;
import sklearn.HasDefaultValue;
import sklearn.SkLearnRegressor;

public class DummyRegressor extends SkLearnRegressor implements HasDefaultValue {

	public DummyRegressor(){
		this("sklearn.dummy", "DummyRegressor");
	}

	public DummyRegressor(String module, String name){
		super(module, name);
	}

	@Override
	public Number getDefaultValue(){
		List<Number> constant = getConstant();

		return Iterables.getOnlyElement(constant);
	}

	@Override
	public RegressionModel encodeModel(Schema schema){
		List<Number> constant = getConstant();

		Number intercept = Iterables.getOnlyElement(constant);

		return RegressionModelUtil.createRegression(Collections.emptyList(), Collections.emptyList(), intercept.doubleValue(), null, schema);
	}

	public List<Number> getConstant(){
		return getNumberArray("constant_");
	}
}
